@@ -119,6 +119,13 @@ class ComplexStep(ApproximationScheme):
             self._fd.compute_approximations(system, jac, total=total)
             return
 
+        saved_inputs = system._inputs._get_data().copy()
+        system._inputs._data.imag[:] = 0.0
+        saved_outputs = system._outputs.asarray(copy=True)
+        system._outputs._data.imag[:] = 0.0
+        saved_resids = system._residuals.asarray(copy=True)
+        system._residuals._data.imag[:] = 0.0
+
         # Turn on complex step.
         system._set_complex_step_mode(True)
 
@@ -127,6 +134,10 @@ class ComplexStep(ApproximationScheme):
         # Turn off complex step.
         system._set_complex_step_mode(False)
 
+        system._inputs.set_val(saved_inputs)
+        system._outputs.set_val(saved_outputs)
+        system._residuals.set_val(saved_resids)
+
     def _get_multiplier(self, delta):
         """
         Return a multiplier to be applied to the jacobian.
