@@ -8,6 +8,7 @@ from numpy import ndarray, imag, complex as npcomplex
 from openmdao.core.explicitcomponent import ExplicitComponent
 from openmdao.utils.units import valid_units
 from openmdao.utils.general_utils import warn_deprecation
+from openmdao.utils import cs_safe
 
 # regex to check for variable names.
 VAR_RGX = re.compile(r'([.]*[_a-zA-Z]\w*[ ]*\(?)')
@@ -73,7 +74,6 @@ class ExecComp(ExplicitComponent):
         Default is None, which means units are provided for variables individually.
     complex_stepsize : double
         Step size used for complex step which is used for derivatives.
-
     """
 
     def initialize(self):
@@ -121,6 +121,7 @@ class ExecComp(ExplicitComponent):
         arcsin(x)                  Inverse sine of x
         arcsinh(x)                 Inverse hyperbolic sine of x
         arctan(x)                  Inverse tangent of x
+        arctan2(y, x)              4-quadrant arctangent function of y and x
         asin(x)                    Inverse sine of x
         asinh(x)                   Inverse hyperbolic sine of x
         atan(x)                    Inverse tangent of x
@@ -221,6 +222,8 @@ class ExecComp(ExplicitComponent):
         self._codes = None
         self._kwargs = kwargs
 
+        self._no_check_partials = True
+
     def setup(self):
         """
         Set up variable name and metadata lists.
@@ -626,7 +629,7 @@ _import_functs(np, _expr_dict,
                       'e', 'pi',  # Constants
                       'isinf', 'isnan',  # Logic
                       'log', 'log10', 'log1p', 'power',  # Math operations
-                      'exp', 'expm1', 'fmax',
+                      'exp', 'expm1', 'fmax', 'min', 'max', 'diff',
                       'fmin', 'maximum', 'minimum',
                       'sum', 'dot', 'prod',  # Reductions
                       'tensordot', 'matmul',  # Linear algebra
@@ -665,18 +668,10 @@ else:
     _expr_dict['factorial'] = factorial
 
 
-# Put any functions here that need special versions to work under
-# complex step
+# put any functions that need custom complex-safe versions here
 
-def _cs_abs(x):
-    if isinstance(x, ndarray):
-        return x * np.sign(x)
-    elif x.real < 0.0:
-        return -x
-    return x
-
-
-_expr_dict['abs'] = _cs_abs
+_expr_dict['abs'] = cs_safe.abs
+_expr_dict['arctan2'] = cs_safe.arctan2
 
 
 class _NumpyMsg(object):
