@@ -16,8 +16,24 @@ except ImportError:
 import openmdao.api as om
 from openmdao.components.exec_comp import _expr_dict
 from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials, assert_warning
+from openmdao.utils import cs_safe
 
 _ufunc_test_data = {
+    'min': {
+        'str': 'f=min(x)',
+        'check_func': np.min,
+        'args': { 'f': {'value': np.zeros(6)},
+                  'x': {'value': np.random.random(6)}}},
+    'max': {
+        'str': 'f=max(x)',
+        'check_func': np.max,
+        'args': { 'f': {'value': np.zeros(6)},
+                  'x': {'value': np.random.random(6)}}},
+    'diff': {
+        'str': 'f=diff(x)',
+        'check_func': np.diff,
+        'args': { 'f': {'value': np.zeros(5)},
+                  'x': {'value': np.random.random(6)}}},
     'abs': {
         'str': 'f=abs(x)',
         'check_func': np.abs,
@@ -72,6 +88,12 @@ _ufunc_test_data = {
         'check_func': np.arctan,
         'args': {'f': {'value': np.zeros(6)},
                  'x': {'value': np.random.random(6)}}},
+    'arctan2': {
+        'str': 'f=arctan2(y, x)',
+        'check_val': np.array([-2.35619449, -0.78539816,  0.78539816,  2.35619449]),
+        'args': {'f': {'value': np.zeros(4)},
+                 'x': {'value': np.array([-1, +1, +1, -1])},
+                 'y': {'value': np.array([-1, -1, +1, +1])}}},
     'atan': {
         'str': 'f=atan(x)',
         'check_func': np.arctan,
@@ -756,6 +778,16 @@ class TestExecComp(unittest.TestCase):
         C1._linearize()
         assert_near_equal(C1._jacobian['y', 'x'], [[2.0]], 0.00001)
 
+    def test_abs_complex_step(self):
+        prob = om.Problem()
+        C1 = prob.model.add_subsystem('C1', om.ExecComp('y=2.0*arctan2(y, x)', x=np.array([1+2j]), y=1))
+
+        prob.setup()
+        prob.set_solver_print(level=0)
+        prob.run_model()
+
+        assert_near_equal(C1._outputs['y'], np.array([1.57079633]), 1e-8)
+
     def test_abs_array_complex_step(self):
         prob = om.Problem()
         C1 = prob.model.add_subsystem('C1', om.ExecComp('y=2.0*abs(x)',
