@@ -18,7 +18,8 @@ from openmdao.utils.units import valid_units
 from openmdao.utils.name_maps import rel_key2abs_key, abs_key2rel_key, rel_name2abs_name
 from openmdao.utils.mpi import MPI
 from openmdao.utils.general_utils import format_as_float_or_array, ensure_compatible, \
-    find_matches, simple_warning, make_set, _is_slicer_op
+    find_matches, simple_warning, make_set, _is_slicer_op, warn_deprecation, convert_src_inds, \
+    _slice_indices
 import openmdao.utils.coloring as coloring_mod
 
 
@@ -76,6 +77,8 @@ class Component(System):
         Cached storage of user-declared partials.
     _declared_partial_checks : list
         Cached storage of user-declared check partial options.
+    _no_check_partials : bool
+        If True, the check_partials function will ignore this component.
     """
 
     def __init__(self, **kwargs):
@@ -97,6 +100,7 @@ class Component(System):
 
         self._declared_partials = defaultdict(dict)
         self._declared_partial_checks = []
+        self._no_check_partials = False
 
     def _declare_options(self):
         """
@@ -466,12 +470,12 @@ class Component(System):
                                                                     ndarray, Iterable)):
             raise TypeError('%s: The src_indices argument should be an int, list, '
                             'tuple, ndarray or Iterable' % self.msginfo)
-        if units is not None and not isinstance(units, str):
-            raise TypeError('%s: The units argument should be a str or None' % self.msginfo)
+        if units is not None:
+            if not isinstance(units, str):
+                raise TypeError('%s: The units argument should be a str or None.' % self.msginfo)
 
-        # Check that units are valid
-        if units is not None and not valid_units(units):
-            raise ValueError("%s: The units '%s' are invalid" % (self.msginfo, units))
+            if not valid_units(units):
+                raise ValueError("%s: The units '%s' are invalid." % (self.msginfo, units))
 
         if tags is not None and not isinstance(tags, (str, list)):
             raise TypeError('The tags argument should be a str or list')
@@ -495,19 +499,27 @@ class Component(System):
                     if flat_src_indices is not None:
                         simple_warning(f"{self.msginfo}: Input '{name}' was added with slice "
                                        "src_indices, so flat_src_indices is ignored.")
-                    flat_src_indices = True
                 else:
                     src_indices = np.asarray(src_indices, dtype=INT_DTYPE)
 
             # value, shape: based on args, making sure they are compatible
             val, shape, src_indices = ensure_compatible(name, val, shape, src_indices)
 
+            if src_indices is not None and src_slice is None and src_indices.ndim == 1:
+                flat_src_indices = True
+
+        if src_indices is not None:
+            warn_deprecation(f"{self.msginfo}: Passing `src_indices` as an arg to `add_input` is"
+                             "deprecated and will become an error in a future release.  Add "
+                             "`src_indices` to a `promotes` or `connect` call instead.")
+
         metadata = {
             'value': val,
             'shape': shape,
             'size': shape_to_len(shape),
             'src_indices': src_indices,  # these will ultimately be converted to a flat index array
             'flat_src_indices': flat_src_indices,
+            'add_input_src_indices': src_indices is not None,
             'src_slice': src_slice,  # store slice def here, if any.  This is never overwritten
             'units': units,
             'desc': desc,
@@ -674,14 +686,14 @@ class Component(System):
         if shape is not None and not isinstance(shape, (int, tuple, list, np.integer)):
             raise TypeError("%s: The shape argument should be an int, tuple, or list but "
                             "a '%s' was given" % (self.msginfo, type(shape)))
-        if units is not None and not isinstance(units, str):
-            raise TypeError('%s: The units argument should be a str or None' % self.msginfo)
         if res_units is not None and not isinstance(res_units, str):
             raise TypeError('%s: The res_units argument should be a str or None' % self.msginfo)
 
-        # Check that units are valid
-        if units is not None and not valid_units(units):
-            raise ValueError("%s: The units '%s' are invalid" % (self.msginfo, units))
+        if units is not None:
+            if not isinstance(units, str):
+                raise TypeError('%s: The units argument should be a str or None' % self.msginfo)
+            if not valid_units(units):
+                raise ValueError("%s: The units '%s' are invalid" % (self.msginfo, units))
 
         if tags is not None and not isinstance(tags, (str, set, list)):
             raise TypeError('The tags argument should be a str, set, or list')
@@ -857,6 +869,7 @@ class Component(System):
         added_src_inds = set()
         for i, iname in enumerate(self._var_allprocs_abs2meta['input']):
             if iname in abs2meta_in and abs2meta_in[iname]['src_indices'] is None:
+                meta_in = abs2meta_in[iname]
                 src = abs_in2out[iname]
                 out_i = all_abs2idx[src]
                 nzs = np.nonzero(sizes_out[:, out_i])[0]
@@ -874,13 +887,19 @@ class Component(System):
                         raise RuntimeError(f"{self.msginfo}: Can't determine src_indices "
                                            f"automatically for input '{iname}'. They must be "
                                            "supplied manually.")
-                simple_warning(f"{self.msginfo}: Component is distributed but input '{iname}' was "
-                               "added without src_indices. Setting src_indices to "
-                               f"range({offset}, {end}).")
-                abs2meta_in[iname]['src_indices'] = np.arange(offset, end, dtype=INT_DTYPE)
+
+                inds = np.arange(offset, end, dtype=INT_DTYPE)
+                if meta_in['shape'] != inds.shape:
+                    inds = inds.reshape(meta_in['shape'])
+                meta_in['src_indices'] = inds
+                meta_in['flat_src_indices'] = True
                 all_abs2meta_in[iname]['has_src_indices'] = True
                 added_src_inds.add(iname)
 
+                simple_warning(f"{self.msginfo}: Component is distributed but input '{iname}' was "
+                               "added without src_indices. Setting src_indices to "
+                               f"np.arange({offset}, {end}, dtype=int).reshape({inds.shape}).")
+
         return added_src_inds
 
     def _approx_partials(self, of, wrt, method='fd', **kwargs):
@@ -1491,6 +1510,37 @@ class Component(System):
                         coloring._check_config_partial(self)
                     self._update_subjac_sparsity(coloring.get_subjac_sparsity())
 
+    def _resolve_src_inds(self, my_tdict, top):
+        abs2meta_in = self._var_abs2meta['input']
+        all_abs2meta_in = self._var_allprocs_abs2meta['input']
+        abs2prom = self._var_allprocs_abs2prom['input']
+
+        for tgt, (pinfo, parent_src_shape, oldprom, oldpath) in my_tdict.items():
+            src_inds, flat_src_inds, src_shape = pinfo
+
+            # update the input metadata with the final src_indices,
+            # flat_src_indices and src_shape
+            if src_inds is None:
+                prom = abs2prom[tgt]
+                if prom in self._var_prom2inds:
+                    del self._var_prom2inds[prom]
+            else:
+                all_abs2meta_in[tgt]['has_src_indices'] = True
+                meta = abs2meta_in[tgt]
+                meta['src_shape'] = src_shape
+                if meta.get('add_input_src_indices'):
+                    src_inds = convert_src_inds(src_inds, src_shape,
+                                                meta['src_indices'], src_shape)
+                elif _is_slicer_op(src_inds):
+                    meta['src_slice'] = src_inds
+                    src_inds = _slice_indices(src_inds, np.prod(parent_src_shape), parent_src_shape)
+                    meta['flat_src_indices'] = True
+                elif src_inds.ndim == 1:
+                    meta['flat_src_indices'] = True
+                elif meta['flat_src_indices'] is None:
+                    meta['flat_src_indices'] = flat_src_inds
+                meta['src_indices'] = src_inds
+
 
 class _DictValues(object):
     """
