@@ -41,7 +41,7 @@ class DistribExecComp(om.ExecComp):
     """
 
     def __init__(self, exprs, arr_size=11, **kwargs):
-        super(DistribExecComp, self).__init__(exprs, **kwargs)
+        super().__init__(exprs, **kwargs)
         self.arr_size = arr_size
         self.options['distributed'] = True
 
@@ -86,12 +86,12 @@ class DistribExecComp(om.ExecComp):
                 meta['value'] = np.ones(sizes[rank], float)
                 meta['src_indices'] = np.arange(start, end, dtype=int)
 
-        super(DistribExecComp, self).setup()
+        super().setup()
 
 
 class DistribCoordComp(om.ExplicitComponent):
     def __init__(self, **kwargs):
-        super(DistribCoordComp, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.options['distributed'] = True
 
@@ -632,7 +632,7 @@ class MPITests2(unittest.TestCase):
         with self.assertRaises(RuntimeError) as context:
             prob.run_model()
 
-        msg = "Group (sub) : Approx_totals is not supported on a group with a distributed "
+        msg = "'sub' <class Group> : Approx_totals is not supported on a group with a distributed "
         msg += "component whose input 'sub.parab.x' is distributed using src_indices. "
         self.assertEqual(str(context.exception), msg)
 
