@@ -25,10 +25,7 @@ from sphinx.writers.html import HTMLTranslator
 from sphinx.writers.html5 import HTML5Translator
 from redbaron import RedBaron
 
-if sys.version_info[0] == 2:
-    import cgi as cgiesc
-else:
-    import html as cgiesc
+import html as cgiesc
 
 from openmdao.utils.general_utils import printoptions
 
