@@ -19,6 +19,7 @@ from openmdao.test_suite.groups.parallel_groups import FanInGrouped
 
 from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.general_utils import run_driver, printoptions
+from openmdao.utils.testing_utils import use_tempdirs
 
 from openmdao.utils.mpi import MPI
 
@@ -105,13 +106,10 @@ class TestErrors(unittest.TestCase):
                          "'cm', 'correlation', 'corr', None].")
 
 
+@use_tempdirs
 class TestDOEDriver(unittest.TestCase):
 
     def setUp(self):
-        self.startdir = os.getcwd()
-        self.tempdir = tempfile.mkdtemp(prefix='TestDOEDriver-')
-        os.chdir(self.tempdir)
-
         self.expected_fullfact3 = [
             {'x': np.array([0.]), 'y': np.array([0.]), 'f_xy': np.array([22.00])},
             {'x': np.array([.5]), 'y': np.array([0.]), 'f_xy': np.array([19.25])},
@@ -126,13 +124,6 @@ class TestDOEDriver(unittest.TestCase):
             {'x': np.array([1.]), 'y': np.array([1.]), 'f_xy': np.array([27.00])},
         ]
 
-    def tearDown(self):
-        os.chdir(self.startdir)
-        try:
-            shutil.rmtree(self.tempdir)
-        except OSError:
-            pass
-
     def test_no_generator(self):
         prob = om.Problem()
         model = prob.model
@@ -153,7 +144,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 0)
 
@@ -185,7 +176,7 @@ class TestDOEDriver(unittest.TestCase):
         expected = self.expected_fullfact3
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 9)
 
@@ -271,10 +262,9 @@ class TestDOEDriver(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.0), promotes=['x'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.0), promotes=['y'])
         model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
-
+        model.set_input_defaults('x', 0.0)
+        model.set_input_defaults('y', 0.0)
         model.add_design_var('x', lower=0.0, upper=1.0)
         model.add_design_var('y', lower=0.0, upper=1.0)
         model.add_objective('f_xy')
@@ -303,7 +293,7 @@ class TestDOEDriver(unittest.TestCase):
         expected = self.expected_fullfact3
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 9)
 
@@ -371,7 +361,7 @@ class TestDOEDriver(unittest.TestCase):
         ]
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 16)
 
@@ -466,9 +456,9 @@ class TestDOEDriver(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.), promotes=['*'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.), promotes=['*'])
         model.add_subsystem('comp', Paraboloid(), promotes=['*'])
+        model.set_input_defaults('x', 0.0)
+        model.set_input_defaults('y', 0.0)
 
         model.add_design_var('x', lower=-10, upper=10)
         model.add_design_var('y', lower=-10, upper=10)
@@ -491,7 +481,7 @@ class TestDOEDriver(unittest.TestCase):
         ]
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 5)
 
@@ -504,10 +494,9 @@ class TestDOEDriver(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.0), promotes=['x'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.0), promotes=['y'])
         model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
-
+        model.set_input_defaults('x', 0.0)
+        model.set_input_defaults('y', 0.0)
         model.add_design_var('x', lower=0.0, upper=1.0)
         model.add_design_var('y', lower=0.0, upper=1.0)
         model.add_objective('f_xy')
@@ -522,7 +511,7 @@ class TestDOEDriver(unittest.TestCase):
         expected = self.expected_fullfact3
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 9)
 
@@ -568,7 +557,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         objs = [int(cr.get_case(case).outputs['f']) for case in cases]
 
@@ -609,7 +598,7 @@ class TestDOEDriver(unittest.TestCase):
         ]
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 9)
 
@@ -645,7 +634,7 @@ class TestDOEDriver(unittest.TestCase):
         ]
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 4)
 
@@ -682,7 +671,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         # The Box-Behnken design for 3 factors involves three blocks, in each of
         # which 2 factors are varied thru the 4 possible combinations of high & low.
@@ -765,7 +754,7 @@ class TestDOEDriver(unittest.TestCase):
         ]
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 4)
 
@@ -833,7 +822,7 @@ class TestDOEDriver(unittest.TestCase):
         ]
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), 4)
 
@@ -883,7 +872,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         self.assertEqual(len(cases), samples)
 
@@ -938,7 +927,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.run_driver()
 
         cr = om.CaseReader("cases.sql")
-        final_case = cr.list_cases('driver')[-1]
+        final_case = cr.list_cases('driver', out_stream=None)[-1]
         outputs = cr.get_case(final_case).outputs
 
         assert_near_equal(outputs['x'], 10.0, 1e-7)
@@ -976,7 +965,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         expected = [{'x': 5, 'y': 1, 'f_xy': 31},
                     {'x': 3, 'y': 6, 'f_xy': 115},
@@ -1027,7 +1016,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         expected = ['abc', None]
 
@@ -1066,7 +1055,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('problem')
+        cases = cr.list_cases('problem', out_stream=None)
 
         case = cr.get_case('end')
         inputs = case.inputs
@@ -1081,11 +1070,6 @@ class TestDOEDriver(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        # Add independent variables
-        indeps = model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
-        indeps.add_discrete_output('x', np.ones((2, ), dtype=np.int))
-        indeps.add_discrete_output('y', np.ones((2, ), dtype=np.int))
-
         # Add components
         model.add_subsystem('parab', ParaboloidDiscreteArray(), promotes=['*'])
 
@@ -1104,11 +1088,15 @@ class TestDOEDriver(unittest.TestCase):
         prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
 
         prob.setup()
+
+        prob.set_val('x', np.ones((2, ), dtype=np.int))
+        prob.set_val('y', np.ones((2, ), dtype=np.int))
+
         prob.run_driver()
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         expected = [{'x': np.array([5, 1]), 'y': np.array([1, 4]), 'f_xy': np.array([31, 69])},
                     {'x': np.array([3, 2]), 'y': np.array([6, -3]), 'f_xy': np.array([115, -7])},
@@ -1122,7 +1110,6 @@ class TestDOEDriver(unittest.TestCase):
                 self.assertEqual(outputs[name][0], expected_case[name][0])
                 self.assertEqual(outputs[name][1], expected_case[name][1])
 
-
     def test_discrete_desvar_csv(self):
         prob = om.Problem()
         model = prob.model
@@ -1159,7 +1146,7 @@ class TestDOEDriver(unittest.TestCase):
         prob.cleanup()
 
         cr = om.CaseReader("cases.sql")
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         expected = [{'x': 5, 'y': 1, 'f_xy': 31},
                     {'x': 3, 'y': 6, 'f_xy': 115},
@@ -1175,15 +1162,12 @@ class TestDOEDriver(unittest.TestCase):
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
+@use_tempdirs
 class TestParallelDOE(unittest.TestCase):
 
     N_PROCS = 4
 
     def setUp(self):
-        self.startdir = os.getcwd()
-        self.tempdir = tempfile.mkdtemp(prefix='TestDOEDriver-')
-        os.chdir(self.tempdir)
-
         self.expected_fullfact3 = [
             {'x': np.array([0.]), 'y': np.array([0.]), 'f_xy': np.array([22.00])},
             {'x': np.array([.5]), 'y': np.array([0.]), 'f_xy': np.array([19.25])},
@@ -1198,13 +1182,6 @@ class TestParallelDOE(unittest.TestCase):
             {'x': np.array([1.]), 'y': np.array([1.]), 'f_xy': np.array([27.00])},
         ]
 
-    def tearDown(self):
-        os.chdir(self.startdir)
-        try:
-            shutil.rmtree(self.tempdir)
-        except OSError:
-            pass
-
     def test_indivisible_error(self):
         prob = om.Problem()
 
@@ -1236,7 +1213,7 @@ class TestParallelDOE(unittest.TestCase):
             prob.setup()
 
         self.assertEqual(str(context.exception),
-                         "FanInGrouped (<model>): MPI process allocation failed: can't meet "
+                         "<model> <class FanInGrouped>: MPI process allocation failed: can't meet "
                          "min_procs required for the following subsystems: ['sub']")
 
     def test_full_factorial(self):
@@ -1274,7 +1251,7 @@ class TestParallelDOE(unittest.TestCase):
         self.assertTrue(expect_msg in output)
 
         cr = om.CaseReader(filename)
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         # cases recorded on this proc
         num_cases = len(cases)
@@ -1292,93 +1269,106 @@ class TestParallelDOE(unittest.TestCase):
         num_cases = prob.comm.allgather(num_cases)
         self.assertEqual(sum(num_cases), len(expected))
 
-    def test_fan_in_grouped(self):
-        # run 2 cases at a time, each using 2 of our 4 procs
-        doe_parallel = 2
+    def test_fan_in_grouped_parallel_2x2(self):
+        # run cases in parallel with 2 procs per model
+        # (cases will be split between the 2 parallel model instances)
+        run_parallel = True
+        procs_per_model = 2
 
         prob = om.Problem(FanInGrouped())
         model = prob.model
 
-        model.add_design_var('iv.x1', lower=0.0, upper=1.0)
-        model.add_design_var('iv.x2', lower=0.0, upper=1.0)
+        model.add_design_var('x1', lower=0.0, upper=1.0)
+        model.add_design_var('x2', lower=0.0, upper=1.0)
 
         model.add_objective('c3.y')
 
         prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=3))
         prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
-        prob.driver.options['run_parallel'] = True
-        prob.driver.options['procs_per_model'] = doe_parallel
+
+        prob.driver.options['run_parallel'] = run_parallel
+        prob.driver.options['procs_per_model'] = procs_per_model
 
         prob.setup()
 
         failed, output = run_driver(prob)
-        self.assertFalse(failed)
 
-        prob.cleanup()
+        from openmdao.utils.mpi import multi_proc_exception_check
 
-        expected = [
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([0.]), 'c3.y': np.array([0.0])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([0.]), 'c3.y': np.array([-3.0])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([0.]), 'c3.y': np.array([-6.0])},
+        with multi_proc_exception_check(prob.comm):
+            self.assertFalse(failed)
 
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([.5]), 'c3.y': np.array([17.5])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([.5]), 'c3.y': np.array([14.5])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([.5]), 'c3.y': np.array([11.5])},
+            prob.cleanup()
 
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([1.]), 'c3.y': np.array([35.0])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([1.]), 'c3.y': np.array([32.0])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([1.]), 'c3.y': np.array([29.0])},
-        ]
+            expected = [
+                {'x1': np.array([0.]), 'x2': np.array([0.]), 'c3.y': np.array([0.0])},
+                {'x1': np.array([.5]), 'x2': np.array([0.]), 'c3.y': np.array([-3.0])},
+                {'x1': np.array([1.]), 'x2': np.array([0.]), 'c3.y': np.array([-6.0])},
 
-        rank = prob.comm.rank
-        size = prob.comm.size // doe_parallel
+                {'x1': np.array([0.]), 'x2': np.array([.5]), 'c3.y': np.array([17.5])},
+                {'x1': np.array([.5]), 'x2': np.array([.5]), 'c3.y': np.array([14.5])},
+                {'x1': np.array([1.]), 'x2': np.array([.5]), 'c3.y': np.array([11.5])},
 
-        num_cases = 0
+                {'x1': np.array([0.]), 'x2': np.array([1.]), 'c3.y': np.array([35.0])},
+                {'x1': np.array([.5]), 'x2': np.array([1.]), 'c3.y': np.array([32.0])},
+                {'x1': np.array([1.]), 'x2': np.array([1.]), 'c3.y': np.array([29.0])},
+            ]
 
-        # cases will be split across files for each proc up to the number requested
-        if rank < doe_parallel:
-            filename = "cases.sql_%d" % rank
+            num_cases = 0
 
-            expect_msg = "Cases from rank %d are being written to %s." % (rank, filename)
-            self.assertTrue(expect_msg in output)
+            # we can run two models in parallel on our 4 procs
+            num_models = prob.comm.size // procs_per_model
 
-            cr = om.CaseReader(filename)
-            cases = cr.list_cases('driver')
+            # a separate case file will be written by rank 0 of each parallel model
+            # (the top two global ranks)
+            rank = prob.comm.rank
 
-            # cases recorded on this proc
-            num_cases = len(cases)
-            self.assertEqual(num_cases, len(expected) // size+(rank < len(expected) % size))
+            if rank < num_models:
+                filename = "cases.sql_%d" % rank
 
-            for n, case in enumerate(cases):
-                idx = n * size + rank  # index of expected case
+                expect_msg = "Cases from rank %d are being written to %s." % (rank, filename)
+                self.assertTrue(expect_msg in output)
 
-                outputs = cr.get_case(case).outputs
+                cr = om.CaseReader(filename)
+                cases = cr.list_cases('driver')
 
-                for name in ('iv.x1', 'iv.x2', 'c3.y'):
-                    self.assertEqual(outputs[name], expected[idx][name])
-        else:
-            self.assertFalse("Cases from rank %d are being written" % rank in output)
+                # cases recorded on this proc
+                num_cases = len(cases)
+                self.assertEqual(num_cases, len(expected) // num_models+(rank < len(expected) % num_models))
+
+                for n, case in enumerate(cases):
+                    idx = n * num_models + rank  # index of expected case
+
+                    outputs = cr.get_case(case).outputs
+
+                    for name in ('x1', 'x2', 'c3.y'):
+                        self.assertEqual(outputs[name], expected[idx][name])
+            else:
+                self.assertFalse("Cases from rank %d are being written" % rank in output)
 
         # total number of cases recorded across all requested procs
         num_cases = prob.comm.allgather(num_cases)
         self.assertEqual(sum(num_cases), len(expected))
 
-    def test_fan_in_grouped_serial(self):
-        # run cases on all procs (parallel model will run on single proc)
-        doe_parallel = 1
+    def test_fan_in_grouped_parallel_4x1(self):
+        # run cases in parallel with 1 proc per model
+        # (cases will be split between the 4 serial model instances)
+        run_parallel = True
+        procs_per_model = 1
 
         prob = om.Problem(FanInGrouped())
         model = prob.model
 
-        model.add_design_var('iv.x1', lower=0.0, upper=1.0)
-        model.add_design_var('iv.x2', lower=0.0, upper=1.0)
+        model.add_design_var('x1', lower=0.0, upper=1.0)
+        model.add_design_var('x2', lower=0.0, upper=1.0)
 
         model.add_objective('c3.y')
 
         prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=3))
         prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
-        prob.driver.options['run_parallel'] = True
-        prob.driver.options['procs_per_model'] = doe_parallel
+
+        prob.driver.options['run_parallel'] = run_parallel
+        prob.driver.options['procs_per_model'] = procs_per_model
 
         prob.setup()
 
@@ -1388,61 +1378,207 @@ class TestParallelDOE(unittest.TestCase):
         prob.cleanup()
 
         expected = [
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([0.]), 'c3.y': np.array([0.0])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([0.]), 'c3.y': np.array([-3.0])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([0.]), 'c3.y': np.array([-6.0])},
+            {'x1': np.array([0.]), 'x2': np.array([0.]), 'c3.y': np.array([0.0])},
+            {'x1': np.array([.5]), 'x2': np.array([0.]), 'c3.y': np.array([-3.0])},
+            {'x1': np.array([1.]), 'x2': np.array([0.]), 'c3.y': np.array([-6.0])},
 
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([.5]), 'c3.y': np.array([17.5])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([.5]), 'c3.y': np.array([14.5])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([.5]), 'c3.y': np.array([11.5])},
+            {'x1': np.array([0.]), 'x2': np.array([.5]), 'c3.y': np.array([17.5])},
+            {'x1': np.array([.5]), 'x2': np.array([.5]), 'c3.y': np.array([14.5])},
+            {'x1': np.array([1.]), 'x2': np.array([.5]), 'c3.y': np.array([11.5])},
 
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([1.]), 'c3.y': np.array([35.0])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([1.]), 'c3.y': np.array([32.0])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([1.]), 'c3.y': np.array([29.0])},
+            {'x1': np.array([0.]), 'x2': np.array([1.]), 'c3.y': np.array([35.0])},
+            {'x1': np.array([.5]), 'x2': np.array([1.]), 'c3.y': np.array([32.0])},
+            {'x1': np.array([1.]), 'x2': np.array([1.]), 'c3.y': np.array([29.0])},
         ]
 
         rank = prob.comm.rank
-        size = prob.comm.size // doe_parallel
 
-        # cases will be split across files for each proc up to the number requested
+        # there will be a separate case file for each proc, containing the cases
+        # run by the instance of the model that runs in serial mode on that proc
         filename = "cases.sql_%d" % rank
 
         expect_msg = "Cases from rank %d are being written to %s." % (rank, filename)
         self.assertTrue(expect_msg in output)
 
+        # we are running 4 models in parallel, each using 1 proc
+        num_models = prob.comm.size // procs_per_model
+
         cr = om.CaseReader(filename)
-        cases = cr.list_cases('driver')
+        cases = cr.list_cases('driver', out_stream=None)
 
         # cases recorded on this proc
         num_cases = len(cases)
-        self.assertEqual(num_cases, len(expected) // size + (rank < len(expected) % size))
+        self.assertEqual(num_cases, len(expected) // num_models + (rank < len(expected) % num_models))
 
         for n, case in enumerate(cases):
-            idx = n * size + rank  # index of expected case
+            idx = n * num_models + rank  # index of expected case
 
             outputs = cr.get_case(case).outputs
 
-            self.assertEqual(outputs['iv.x1'], expected[idx]['iv.x1'])
-            self.assertEqual(outputs['iv.x2'], expected[idx]['iv.x2'])
+            self.assertEqual(outputs['x1'], expected[idx]['x1'])
+            self.assertEqual(outputs['x2'], expected[idx]['x2'])
             self.assertEqual(outputs['c3.y'], expected[idx]['c3.y'])
 
         # total number of cases recorded across all requested procs
         num_cases = prob.comm.allgather(num_cases)
         self.assertEqual(sum(num_cases), len(expected))
 
+    def test_fan_in_grouped_serial_2x2(self):
+        # do not run cases in parallel, but with 2 procs per model
+        # (all cases will run on each of the 2 parallel model instances)
+        run_parallel = False
+        procs_per_model = 2
 
+        prob = om.Problem(FanInGrouped())
+        model = prob.model
+
+        model.add_design_var('x1', lower=0.0, upper=1.0)
+        model.add_design_var('x2', lower=0.0, upper=1.0)
+        model.add_objective('c3.y')
+
+        prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=3))
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.driver.options['run_parallel'] = run_parallel
+        prob.driver.options['procs_per_model'] = procs_per_model
+
+        prob.setup()
+
+        failed, output = run_driver(prob)
+        self.assertFalse(failed)
+
+        prob.cleanup()
+
+        expected = [
+            {'x1': np.array([0.]), 'x2': np.array([0.]), 'c3.y': np.array([0.0])},
+            {'x1': np.array([.5]), 'x2': np.array([0.]), 'c3.y': np.array([-3.0])},
+            {'x1': np.array([1.]), 'x2': np.array([0.]), 'c3.y': np.array([-6.0])},
+
+            {'x1': np.array([0.]), 'x2': np.array([.5]), 'c3.y': np.array([17.5])},
+            {'x1': np.array([.5]), 'x2': np.array([.5]), 'c3.y': np.array([14.5])},
+            {'x1': np.array([1.]), 'x2': np.array([.5]), 'c3.y': np.array([11.5])},
+
+            {'x1': np.array([0.]), 'x2': np.array([1.]), 'c3.y': np.array([35.0])},
+            {'x1': np.array([.5]), 'x2': np.array([1.]), 'c3.y': np.array([32.0])},
+            {'x1': np.array([1.]), 'x2': np.array([1.]), 'c3.y': np.array([29.0])},
+        ]
+
+        num_cases = 0
+
+        rank = prob.comm.rank
+
+        # we are running the model on two sets of two procs
+        num_models = prob.comm.size // procs_per_model
+
+        if rank < num_models:
+            # a separate case file will be written by rank 0 of each parallel model
+            # (the top two global ranks)
+            filename = "cases.sql_%d" % rank
+
+            expect_msg = "Cases from rank %d are being written to %s." % (rank, filename)
+            self.assertTrue(expect_msg in output)
+
+            cr = om.CaseReader(filename)
+            cases = cr.list_cases('driver', out_stream=None)
+
+            # cases recorded on this proc... each proc will run all cases
+            num_cases = len(cases)
+            self.assertEqual(num_cases, len(expected))
+
+            for idx, case in enumerate(cases):
+                outputs = cr.get_case(case).outputs
+
+                self.assertEqual(outputs['x1'], expected[idx]['x1'])
+                self.assertEqual(outputs['x2'], expected[idx]['x2'])
+                self.assertEqual(outputs['c3.y'], expected[idx]['c3.y'])
+
+        # total number of cases recorded will be twice the number of cases
+        # (every case will be recorded on all pairs of procs)
+        num_cases = prob.comm.allgather(num_cases)
+        self.assertEqual(sum(num_cases), num_models*len(expected))
+
+    def test_fan_in_grouped_serial_4x1(self):
+        # do not run cases in parallel, with 1 proc per model
+        # (all cases will run on each of the 4 serial model instances)
+        run_parallel = False
+        procs_per_model = 1
+
+        prob = om.Problem(FanInGrouped())
+        model = prob.model
+
+        model.add_design_var('x1', lower=0.0, upper=1.0)
+        model.add_design_var('x2', lower=0.0, upper=1.0)
+        model.add_objective('c3.y')
+
+        prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=3))
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.driver.options['run_parallel'] = run_parallel
+        prob.driver.options['procs_per_model'] = procs_per_model
+
+        prob.setup()
+
+        failed, output = run_driver(prob)
+        self.assertFalse(failed)
+
+        prob.cleanup()
+
+        expected = [
+            {'x1': np.array([0.]), 'x2': np.array([0.]), 'c3.y': np.array([0.0])},
+            {'x1': np.array([.5]), 'x2': np.array([0.]), 'c3.y': np.array([-3.0])},
+            {'x1': np.array([1.]), 'x2': np.array([0.]), 'c3.y': np.array([-6.0])},
+
+            {'x1': np.array([0.]), 'x2': np.array([.5]), 'c3.y': np.array([17.5])},
+            {'x1': np.array([.5]), 'x2': np.array([.5]), 'c3.y': np.array([14.5])},
+            {'x1': np.array([1.]), 'x2': np.array([.5]), 'c3.y': np.array([11.5])},
+
+            {'x1': np.array([0.]), 'x2': np.array([1.]), 'c3.y': np.array([35.0])},
+            {'x1': np.array([.5]), 'x2': np.array([1.]), 'c3.y': np.array([32.0])},
+            {'x1': np.array([1.]), 'x2': np.array([1.]), 'c3.y': np.array([29.0])},
+        ]
+
+        rank = prob.comm.rank
+
+        # we are running the model on all four procs
+        num_models = prob.comm.size // procs_per_model
+
+        # there will be a separate case file for each proc, containing the cases
+        # run by the instance of the model that runs in serial mode on that proc
+        filename = "cases.sql_%d" % rank
+
+        expect_msg = "Cases from rank %d are being written to %s." % (rank, filename)
+        self.assertTrue(expect_msg in output)
+
+        # we are running 4 models in parallel, each using 1 proc
+        num_models = prob.comm.size // procs_per_model
+
+        cr = om.CaseReader(filename)
+        cases = cr.list_cases('driver', out_stream=None)
+
+        # cases recorded on this proc
+        num_cases = len(cases)
+        self.assertEqual(num_cases, len(expected))
+
+        for idx, case in enumerate(cases):
+            outputs = cr.get_case(case).outputs
+
+            self.assertEqual(outputs['x1'], expected[idx]['x1'])
+            self.assertEqual(outputs['x2'], expected[idx]['x2'])
+            self.assertEqual(outputs['c3.y'], expected[idx]['c3.y'])
+
+        # total number of cases recorded will be 4x the number of cases
+        # (every case will be recorded on all procs)
+        num_cases = prob.comm.allgather(num_cases)
+        self.assertEqual(sum(num_cases), num_models*len(expected))
+
+
+@use_tempdirs
 class TestDOEDriverFeature(unittest.TestCase):
 
     def setUp(self):
         import json
-        import os
-        import tempfile
         import numpy as np
 
-        self.startdir = os.getcwd()
-        self.tempdir = tempfile.mkdtemp(prefix='TestDOEDriverFeature-')
-        os.chdir(self.tempdir)
-
         self.expected_csv = '\n'.join([
             " x ,   y",
             "0.0,  0.0",
@@ -1489,16 +1625,6 @@ class TestDOEDriverFeature(unittest.TestCase):
         with open('cases.json', 'w') as f:
             f.write(self.expected_json)
 
-    def tearDown(self):
-        import os
-        import shutil
-
-        os.chdir(self.startdir)
-        try:
-            shutil.rmtree(self.tempdir)
-        except OSError:
-            pass
-
     def test_uniform(self):
         import openmdao.api as om
         from openmdao.test_suite.components.paraboloid import Paraboloid
@@ -1506,8 +1632,6 @@ class TestDOEDriverFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.), promotes=['*'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.), promotes=['*'])
         model.add_subsystem('comp', Paraboloid(), promotes=['*'])
 
         model.add_design_var('x', lower=-10, upper=10)
@@ -1518,6 +1642,10 @@ class TestDOEDriverFeature(unittest.TestCase):
         prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
 
         prob.setup()
+
+        prob.set_val('x', 0.0)
+        prob.set_val('y', 0.0)
+
         prob.run_driver()
         prob.cleanup()
 
@@ -1540,8 +1668,6 @@ class TestDOEDriverFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.0), promotes=['x'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.0), promotes=['y'])
         model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
 
         model.add_design_var('x', lower=0.0, upper=1.0)
@@ -1550,6 +1676,9 @@ class TestDOEDriverFeature(unittest.TestCase):
 
         prob.setup()
 
+        prob.set_val('x', 0.0)
+        prob.set_val('y', 0.0)
+
         # this file contains design variable inputs in CSV format
         with open('cases.csv', 'r') as f:
             self.assertEqual(f.read(), self.expected_csv)
@@ -1581,8 +1710,6 @@ class TestDOEDriverFeature(unittest.TestCase):
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.0), promotes=['x'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.0), promotes=['y'])
         model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
 
         model.add_design_var('x', lower=0.0, upper=1.0)
@@ -1591,6 +1718,9 @@ class TestDOEDriverFeature(unittest.TestCase):
 
         prob.setup()
 
+        prob.set_val('x', 0.0)
+        prob.set_val('y', 0.0)
+
         # load design variable inputs from JSON file and decode into list
         with open('cases.json', 'r') as f:
             json_data = f.read()
@@ -1625,13 +1755,12 @@ class TestDOEDriverFeature(unittest.TestCase):
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
+@use_tempdirs
 class TestParallelDOEFeature(unittest.TestCase):
 
     N_PROCS = 2
 
     def setUp(self):
-        import os
-        import tempfile
         import numpy as np
 
         from mpi4py import MPI
@@ -1661,18 +1790,6 @@ class TestParallelDOEFeature(unittest.TestCase):
             "x: %5.2f, y: %5.2f, f_xy: %6.2f" % xyf for xyf in values
         ])
 
-        # run in temp dir
-        self.startdir = os.getcwd()
-        self.tempdir = tempfile.mkdtemp(prefix='TestParallelDOEFeature-')
-        os.chdir(self.tempdir)
-
-    def tearDown(self):
-        os.chdir(self.startdir)
-        try:
-            shutil.rmtree(self.tempdir)
-        except OSError:
-            pass
-
     def test_full_factorial(self):
         import openmdao.api as om
         from openmdao.test_suite.components.paraboloid import Paraboloid
@@ -1680,15 +1797,11 @@ class TestParallelDOEFeature(unittest.TestCase):
         from mpi4py import MPI
 
         prob = om.Problem()
-        model = prob.model
 
-        model.add_subsystem('p1', om.IndepVarComp('x', 0.0), promotes=['x'])
-        model.add_subsystem('p2', om.IndepVarComp('y', 0.0), promotes=['y'])
-        model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
-
-        model.add_design_var('x', lower=0.0, upper=1.0)
-        model.add_design_var('y', lower=0.0, upper=1.0)
-        model.add_objective('f_xy')
+        prob.model.add_subsystem('comp', Paraboloid(), promotes=['x', 'y', 'f_xy'])
+        prob.model.add_design_var('x', lower=0.0, upper=1.0)
+        prob.model.add_design_var('y', lower=0.0, upper=1.0)
+        prob.model.add_objective('f_xy')
 
         prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=3))
         prob.driver.options['run_parallel'] = True
@@ -1721,54 +1834,39 @@ class TestParallelDOEFeature(unittest.TestCase):
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
+@use_tempdirs
 class TestParallelDOEFeature2(unittest.TestCase):
 
     N_PROCS = 4
 
     def setUp(self):
-        import os
-        import shutil
-        import tempfile
-
         from mpi4py import MPI
         rank = MPI.COMM_WORLD.rank
 
         expected = [
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([0.]), 'c3.y': np.array([0.00])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([0.]), 'c3.y': np.array([-3.00])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([0.]), 'c3.y': np.array([-6.00])},
+            {'x1': np.array([0.]), 'x2': np.array([0.]), 'c3.y': np.array([0.00])},
+            {'x1': np.array([.5]), 'x2': np.array([0.]), 'c3.y': np.array([-3.00])},
+            {'x1': np.array([1.]), 'x2': np.array([0.]), 'c3.y': np.array([-6.00])},
 
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([.5]), 'c3.y': np.array([17.50])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([.5]), 'c3.y': np.array([14.50])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([.5]), 'c3.y': np.array([11.50])},
+            {'x1': np.array([0.]), 'x2': np.array([.5]), 'c3.y': np.array([17.50])},
+            {'x1': np.array([.5]), 'x2': np.array([.5]), 'c3.y': np.array([14.50])},
+            {'x1': np.array([1.]), 'x2': np.array([.5]), 'c3.y': np.array([11.50])},
 
-            {'iv.x1': np.array([0.]), 'iv.x2': np.array([1.]), 'c3.y': np.array([35.00])},
-            {'iv.x1': np.array([.5]), 'iv.x2': np.array([1.]), 'c3.y': np.array([32.00])},
-            {'iv.x1': np.array([1.]), 'iv.x2': np.array([1.]), 'c3.y': np.array([29.00])},
+            {'x1': np.array([0.]), 'x2': np.array([1.]), 'c3.y': np.array([35.00])},
+            {'x1': np.array([.5]), 'x2': np.array([1.]), 'c3.y': np.array([32.00])},
+            {'x1': np.array([1.]), 'x2': np.array([1.]), 'c3.y': np.array([29.00])},
         ]
 
         # expect odd cases on rank 0 and even cases on rank 1
         values = []
         for idx, case in enumerate(expected):
             if idx % 2 == rank:
-                values.append((case['iv.x1'], case['iv.x2'], case['c3.y']))
+                values.append((case['x1'], case['x2'], case['c3.y']))
 
         self.expect_text = "\n"+"\n".join([
-            "iv.x1: %5.2f, iv.x2: %5.2f, c3.y: %6.2f" % vals_i for vals_i in values
+            "x1: %5.2f, x2: %5.2f, c3.y: %6.2f" % vals_i for vals_i in values
         ])
 
-        # run in temp dir
-        self.startdir = os.getcwd()
-        self.tempdir = tempfile.mkdtemp(prefix='TestParallelDOEFeature2-')
-        os.chdir(self.tempdir)
-
-    def tearDown(self):
-        os.chdir(self.startdir)
-        try:
-            shutil.rmtree(self.tempdir)
-        except OSError:
-            pass
-
     def test_fan_in_grouped(self):
         import openmdao.api as om
         from openmdao.test_suite.groups.parallel_groups import FanInGrouped
@@ -1776,28 +1874,30 @@ class TestParallelDOEFeature2(unittest.TestCase):
         from mpi4py import MPI
 
         prob = om.Problem(FanInGrouped())
-        model = prob.model
 
-        model.add_design_var('iv.x1', lower=0.0, upper=1.0)
-        model.add_design_var('iv.x2', lower=0.0, upper=1.0)
-
-        model.add_objective('c3.y')
+        prob.model.add_design_var('x1', lower=0.0, upper=1.0)
+        prob.model.add_design_var('x2', lower=0.0, upper=1.0)
+        prob.model.add_objective('c3.y')
 
         prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=3))
         prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
-        prob.driver.options['run_parallel'] = True
 
-        # run 2 cases at a time, each using 2 of our 4 procs
-        doe_parallel = prob.driver.options['procs_per_model'] = 2
+        # the FanInGrouped model uses 2 processes, so we can run
+        # two instances of the model at a time, each using 2 of our 4 procs
+        prob.driver.options['run_parallel'] = True
+        prob.driver.options['procs_per_model'] = procs_per_model = 2
 
         prob.setup()
         prob.run_driver()
         prob.cleanup()
 
-        rank = MPI.COMM_WORLD.rank
+        # a separate case file will be written by rank 0 of each parallel model
+        # (the top two global ranks)
+        rank = prob.comm.rank
 
-        # check recorded cases from each case file
-        if rank < doe_parallel:
+        num_models = prob.comm.size // procs_per_model
+
+        if rank < num_models:
             filename = "cases.sql_%d" % rank
 
             cr = om.CaseReader(filename)
@@ -1806,29 +1906,18 @@ class TestParallelDOEFeature2(unittest.TestCase):
             values = []
             for case in cases:
                 outputs = cr.get_case(case).outputs
-                values.append((outputs['iv.x1'], outputs['iv.x2'], outputs['c3.y']))
+                values.append((outputs['x1'], outputs['x2'], outputs['c3.y']))
 
-            self.assertEqual("\n"+"\n".join(["iv.x1: %5.2f, iv.x2: %5.2f, c3.y: %6.2f" % (x1, x2, y) for x1, x2, y in values]),
+            self.assertEqual("\n"+"\n".join(["x1: %5.2f, x2: %5.2f, c3.y: %6.2f" % (x1, x2, y) for x1, x2, y in values]),
                 self.expect_text)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
+@use_tempdirs
 class TestParallelDistribDOE(unittest.TestCase):
 
     N_PROCS = 4
 
-    def setUp(self):
-        self.startdir = os.getcwd()
-        self.tempdir = tempfile.mkdtemp(prefix='TestDOEDriver-')
-        os.chdir(self.tempdir)
-
-    def tearDown(self):
-        os.chdir(self.startdir)
-        try:
-            shutil.rmtree(self.tempdir)
-        except OSError:
-            pass
-
     def test_doe_distributed_var(self):
         size = 3
 
