@@ -473,11 +473,10 @@ def assertViewerDataRecorded(test, expected):
 
         # model tree
         tr = model_viewer_data['tree']
-        test.assertEqual(expected['tree_length'], len(tr))
-
         test.assertEqual({'name', 'type', 'subsystem_type', 'children', 'linear_solver',
                           'nonlinear_solver', 'is_parallel', 'component_type', 'class',
-                          'expressions'},
+                          'expressions', 'options', 'linear_solver_options',
+                          'nonlinear_solver_options'},
                          set(tr.keys()))
         test.assertEqual(expected['tree_children_length'],
                          len(model_viewer_data['tree']['children']))
@@ -489,6 +488,7 @@ def assertViewerDataRecorded(test, expected):
                 for var in expected['abs2prom'][io]:
                     test.assertEqual(abs2prom[io][var], expected['abs2prom'][io][var])
 
+        return model_viewer_data
 
 def assertSystemMetadataIdsRecorded(test, ids):
 
