@@ -49,7 +49,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_outputs.set_val(0.0)
         group.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         # reverse
@@ -57,7 +57,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_residuals.set_val(0.0)
         group.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
     def test_solve_linear_ksp_gmres(self):
@@ -80,7 +80,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_outputs.set_val(0.0)
         group.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         # reverse
@@ -88,7 +88,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_residuals.set_val(0.0)
         group.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
     def test_solve_linear_ksp_maxiter(self):
@@ -140,7 +140,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_outputs.set_val(0.0)
         group.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         self.assertTrue(precon._iter_count > 0)
@@ -150,7 +150,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_residuals.set_val(0.0)
         group.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 3e-15)
 
         self.assertTrue(precon._iter_count > 0)
@@ -170,7 +170,7 @@ class TestPETScKrylov(unittest.TestCase):
         group.linear_solver._linearize()
         group.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         # reverse
@@ -179,7 +179,7 @@ class TestPETScKrylov(unittest.TestCase):
         group.linear_solver._linearize()
         group.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 3e-15)
 
     def test_solve_linear_ksp_precon_left(self):
@@ -205,7 +205,7 @@ class TestPETScKrylov(unittest.TestCase):
         group.run_linearize()
         group.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         # reverse
@@ -214,7 +214,7 @@ class TestPETScKrylov(unittest.TestCase):
         group.run_linearize()
         group.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 3e-15)
 
         # test the direct solver and make sure KSP correctly recurses for _linearize
@@ -235,7 +235,7 @@ class TestPETScKrylov(unittest.TestCase):
         group.linear_solver._linearize()
         group.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, group.expected_solution, 1e-15)
 
         # reverse
@@ -244,7 +244,7 @@ class TestPETScKrylov(unittest.TestCase):
         group.linear_solver._linearize()
         group.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, group.expected_solution, 3e-15)
 
     def test_solve_on_subsystem(self):
@@ -272,7 +272,7 @@ class TestPETScKrylov(unittest.TestCase):
         d_outputs.set_val(0.0)
         g1.run_solve_linear(['linear'], 'fwd')
 
-        output = d_outputs._data
+        output = d_outputs.asarray()
         assert_near_equal(output, g1.expected_solution, 1e-15)
 
         # reverse
@@ -283,7 +283,7 @@ class TestPETScKrylov(unittest.TestCase):
         g1.linear_solver._linearize()
         g1.run_solve_linear(['linear'], 'rev')
 
-        output = d_residuals._data
+        output = d_residuals.asarray()
         assert_near_equal(output, g1.expected_solution, 3e-15)
 
     def test_linear_solution_cache(self):
