@@ -60,6 +60,6 @@ class NonlinearBlockJac(NonlinearSolver):
         # If this is a parallel group, check for analysis errors and reraise.
         if len(system._subsystems_myproc) != len(system._subsystems_allprocs):
             with multi_proc_fail_check(system.comm):
-                super(NonlinearBlockJac, self)._run_apply()
+                super()._run_apply()
         else:
-            super(NonlinearBlockJac, self)._run_apply()
+            super()._run_apply()
