@@ -941,9 +941,9 @@ class BlockLinearSolver(LinearSolver):
         system = self._system()
         for vec_name in system._lin_rel_vec_name_list:
             if self._mode == 'fwd':
-                self._rhs_vecs[vec_name][:] = system._vectors['residual'][vec_name]._data
+                self._rhs_vecs[vec_name][:] = system._vectors['residual'][vec_name].asarray()
             else:
-                self._rhs_vecs[vec_name][:] = system._vectors['output'][vec_name]._data
+                self._rhs_vecs[vec_name][:] = system._vectors['output'][vec_name].asarray()
 
     def _set_complex_step_mode(self, active):
         """
@@ -1003,7 +1003,7 @@ class BlockLinearSolver(LinearSolver):
 
         norm = 0
         for vec_name in system._lin_rel_vec_name_list:
-            b_vecs[vec_name]._data -= self._rhs_vecs[vec_name]
+            b_vecs[vec_name] -= self._rhs_vecs[vec_name]
             norm += b_vecs[vec_name].get_norm()**2
 
         return norm ** 0.5
