@@ -8,6 +8,7 @@ import warnings
 import unittest
 from fnmatch import fnmatchcase
 from io import StringIO
+from numbers import Number
 
 # note: this is a Python 3.3 change, clean this up for OpenMDAO 3.x
 try:
@@ -29,6 +30,27 @@ from openmdao.core.constants import INT_DTYPE
 _ignore_errors = False
 
 
+def _convert_auto_ivc_to_conn_name(conns_dict, name):
+    """
+    Convert name of auto_ivc val to promoted input name.
+
+    Parameters
+    ----------
+    conns_dict : dict
+        Dictionary of global connections.
+    name : str
+        Name of auto_ivc to be found.
+
+    Returns
+    -------
+    str
+        Promoted input name.
+    """
+    for key, val in conns_dict.items():
+        if val == name:
+            return key
+
+
 def ignore_errors(flag=None):
     """
     Disable certain errors that will prevent setup from completing.
@@ -846,14 +868,49 @@ def make_serializable(o):
     """
     if isinstance(o, _container_classes):
         return [make_serializable(item) for item in o]
+    elif isinstance(o, dict):
+        s_key = [make_serializable_key(item) for item in o.keys()]
+        s_val = [make_serializable(item) for item in o.values()]
+        return dict(zip(s_key, s_val))
     elif isinstance(o, np.ndarray):
         return o.tolist()
     elif isinstance(o, np.number):
         return o.item()
+    elif isinstance(o, (str, float, int)):
+        return o
+    elif isinstance(o, bool) or isinstance(o, complex):
+        return str(o)
+    elif hasattr(o, '__dict__'):
+        return o.__class__.__name__
+    else:
+        return o
+
+
+def make_serializable_key(o):
+    """
+    Recursively convert numpy types to native types for JSON serialization.
+
+    This function is for making serizializable dictionary keys, so no containers.
+    This function should NOT be passed into json.dump or json.dumps as the 'default' arg.
+
+    Parameters
+    ----------
+    o : object
+        the object to be converted
+
+    Returns
+    -------
+    object
+        The converted object.
+    """
+    if isinstance(o, str):
+        return o
+    elif isinstance(o, np.number):
+        return o.item()
     elif hasattr(o, '__dict__'):
         return o.__class__.__name__
     else:
-        return o
+        return str(o)
 
 
 def default_noraise(o):
@@ -875,13 +932,23 @@ def default_noraise(o):
         The converted object.
     """
     if isinstance(o, _container_classes):
-        return [make_serializable(item) for item in o]
+        return [default_noraise(item) for item in o]
+    elif isinstance(o, dict):
+        s_key = [make_serializable_key(item) for item in o.keys()]
+        s_val = [default_noraise(item) for item in o.values()]
+        return dict(zip(s_key, s_val))
     elif isinstance(o, np.ndarray):
         return o.tolist()
     elif isinstance(o, np.number):
         return o.item()
+    elif isinstance(o, (str, float, int)):
+        return o
+    elif isinstance(o, bool) or isinstance(o, complex):
+        return str(o)
     elif hasattr(o, '__dict__'):
         return o.__class__.__name__
+    elif o is None:
+        return None
     else:
         return f"unserializable object ({type(o).__name__})"
 
@@ -907,10 +974,19 @@ def make_set(str_data, name=None):
         return set()
     elif isinstance(str_data, str):
         return {str_data}
-    elif isinstance(str_data, set):
-        return str_data
-    elif isinstance(str_data, list):
-        return set(str_data)
+    elif isinstance(str_data, (set, list)):
+
+        for item in str_data:
+            if not isinstance(item, str):
+                typ = type(item).__name__
+                msg = f"Items in tags should be of type string, but type '{typ}' was found."
+                raise TypeError(msg)
+
+        if isinstance(str_data, set):
+            return str_data
+        elif isinstance(str_data, list):
+            return set(str_data)
+
     elif name:
         raise TypeError("The {} argument should be str, set, or list: {}".format(name, str_data))
     else:
@@ -1111,3 +1187,167 @@ def prom2ivc_src_dict(prom_dict):
             src_dict[name] = meta
 
     return src_dict
+
+
+def convert_src_inds(parent_src_inds, parent_src_shape, my_src_inds, my_src_shape):
+    """
+    Compute lower level src_indices based on parent src_indices.
+
+    Parameters
+    ----------
+    parent_src_inds : ndarray
+        Parent src_indices.
+    parent_src_shape : tuple
+        Shape of source expected by parent.
+    my_src_inds : ndarray or fancy index
+        src_indices at the current system level, before conversion.
+    my_src_shape : tuple
+        Expected source shape at the current system level.
+
+    Returns
+    -------
+    ndarray
+        Final src_indices based on those of the parent.
+    """
+    if parent_src_inds is None:
+        return my_src_inds
+    elif my_src_inds is None:
+        return parent_src_inds
+    if isinstance(my_src_inds, tuple):
+        ndims = len(my_src_inds)
+    elif isinstance(my_src_inds, np.ndarray):
+        ndims = my_src_inds.ndim
+    else:  # slice
+        ndims = 1
+    if _is_slicer_op(parent_src_inds):
+        parent_src_inds = _slice_indices(parent_src_inds, np.prod(parent_src_shape),
+                                         parent_src_shape)
+    if ndims == 1:
+        return parent_src_inds.ravel()[my_src_inds]
+    else:
+        return parent_src_inds.reshape(my_src_shape)[my_src_inds]
+
+
+def shape_from_idx(src_shape, src_inds, flat_src_inds):
+    """
+    Get the shape of the result if the given src_inds were applied to an array of the given shape.
+
+    Parameters
+    ----------
+    src_shape : tuple
+        Expected shape of source variable.
+    src_inds : ndarray or fancy index
+        Indices into the source variable.
+    flat_src_inds : bool
+        If True, src_inds index into a flat array.
+
+    Returns
+    -------
+    tuple
+        Shape of the input.
+    """
+    if _is_slicer_op(src_inds):
+        if isinstance(src_inds, slice):
+            src_inds = [src_inds]
+
+        for entry in src_inds:
+            if entry is Ellipsis:
+                shp = np.empty(src_shape, dtype=bool)[src_inds].shape
+                if flat_src_inds:
+                    return (np.product(shp),)
+                return shp
+
+        if len(src_inds) != len(src_shape):
+            raise ValueError(f"src_indices {src_inds} have the wrong number of dimensions, "
+                             f"{len(src_inds)}, to index into an array of shape {src_shape}")
+
+        ret = []
+        full_slice = slice(None)
+        for i, dimsize in enumerate(src_shape):
+            slc = src_inds[i]
+            if isinstance(slc, slice):
+                if slc == full_slice:
+                    ret.append(dimsize)
+                elif (slc.start is None or slc.start < 0 or slc.stop is None or
+                      slc.stop < 0 or (slc.step is not None and slc.step < 0)):
+                    ret.append(np.empty(dimsize, dtype=bool)[slc].size)
+                else:
+                    step = slc.step
+                    if step in (None, 1):
+                        ret.append(slc.stop - slc.start)
+                    else:
+                        ret.append(1 + (slc.stop - slc.start - 1) // slc.step)
+            elif isinstance(slc, Number):
+                ret.append(1)
+            else:  # list/tuple/array
+                ret.append(len(slc))
+        return tuple(ret)
+    else:
+        if src_inds.ndim == 1:
+            flat_src_inds = True
+        if flat_src_inds:
+            return src_inds.shape
+        elif src_inds.size > 0:
+            dims = src_inds.shape[-1]
+        else:
+            return (0,)
+
+        if len(src_shape) != dims:
+            raise ValueError(f"non-flat src_indices {src_inds} have the wrong number of dimensions,"
+                             f" {dims}, to index into an array of shape {src_shape}")
+        return tuple(src_inds.shape[:-1])
+
+
+def shape2tuple(shape):
+    """
+    Return shape as a tuple.
+
+    Parameters
+    ----------
+    shape : int or tuple
+        The given shape.
+
+    Returns
+    -------
+    tuple
+        The shape as a tuple.
+    """
+    if isinstance(shape, Number):
+        return (shape,)
+    elif shape is None:
+        return shape
+    return tuple(shape)
+
+
+def get_connection_owner(system, tgt):
+    """
+    Return (owner, promoted_src, promoted_tgt) for the given connected source and target.
+
+    Note: this is not speedy.  It's intended for use only in error messages.
+
+    Parameters
+    ----------
+    system : System
+        Any System.  The search always goes from the model level down.
+    tgt : str
+        Absolute pathname of the target variable.
+
+    Returns
+    -------
+    tuple
+        (owning group, promoted source name, promoted target name)
+    """
+    from openmdao.core.group import Group
+
+    model = system._problem_meta['model_ref']()
+    src = model._conn_global_abs_in2out[tgt]
+
+    if model._var_allprocs_abs2prom['input'][tgt] != model._var_allprocs_abs2prom['output'][src]:
+        # connection is explicit
+        for g in model.system_iter(include_self=True, recurse=True, typ=Group):
+            if g._manual_connections:
+                tprom = g._var_allprocs_abs2prom['input'][tgt]
+                if tprom in g._manual_connections:
+                    return g.pathname, g._var_allprocs_abs2prom['output'][src], tprom
+
+    return None, None, None
