@@ -35,21 +35,70 @@ _IND = 4  # HTML indentation (spaces)
 _MAX_ARRAY_SIZE_FOR_REPR_VAL = 1000  # If var has more elements than this do not pass to N2
 
 
+def _convert_nans_in_nested_list(val_as_list):
+    """
+    Given a list, possibly nested, replace any numpy.nan values with the string "nan".
+
+    This is done since JSON does not handle nan. This code is used to pass variable values
+    to the N2 diagram.
+
+    The modifications to the list values are done in-place to avoid excessive copying of lists.
+
+    Parameters
+    ----------
+    val_as_list : list, possibly nested
+        the list whose nan elements need to be converted
+    """
+    for i, val in enumerate(val_as_list):
+        if isinstance(val, list):
+            _convert_nans_in_nested_list(val)
+        else:
+            if np.isnan(val):
+                val_as_list[i] = "nan"
+            elif np.isinf(val):
+                val_as_list[i] = "infinity"
+            else:
+                val_as_list[i] = val
+
+
+def _convert_ndarray_to_support_nans_in_json(val):
+    """
+    Given numpy array of arbitrary dimensions, return the equivalent nested list with nan replaced.
+
+    numpy.nan values are replaced with the string "nan".
+
+    Parameters
+    ----------
+    val : ndarray
+        the numpy array to be converted
+
+    Returns
+    -------
+    object : list, possibly nested
+        The equivalent list with any nan values replaced with the string "nan".
+    """
+    val_as_list = val.tolist()
+    _convert_nans_in_nested_list(val_as_list)
+    return(val_as_list)
+
+
 def _get_var_dict(system, typ, name):
     if name in system._var_discrete[typ]:
         meta = system._var_discrete[typ][name]
         is_discrete = True
     else:
-        meta = system._var_abs2meta[name]
+        if name in system._var_abs2meta['output']:
+            meta = system._var_abs2meta['output'][name]
+        else:
+            meta = system._var_abs2meta['input'][name]
         name = system._var_abs2prom[typ][name]
         is_discrete = False
 
     var_dict = OrderedDict()
 
     var_dict['name'] = name
-    if typ == 'input':
-        var_dict['type'] = 'input'
-    elif typ == 'output':
+    var_dict['type'] = typ
+    if typ == 'output':
         isimplicit = isinstance(system, ImplicitComponent)
         var_dict['type'] = 'output'
         var_dict['implicit'] = isimplicit
@@ -70,20 +119,50 @@ def _get_var_dict(system, typ, name):
     var_dict['is_discrete'] = is_discrete
 
     if is_discrete:
-        if isinstance(meta['value'], (int, str, list, dict, complex, np.ndarray)):
-            val = meta['value']
-            var_dict['value'] = val
+        if isinstance(meta['value'], (int, str, list, dict, complex, np.ndarray)) or MPI is None:
+            var_dict['value'] = default_noraise(system.get_val(name))
         else:
             var_dict['value'] = type(meta['value']).__name__
     else:
         if meta['value'].size < _MAX_ARRAY_SIZE_FOR_REPR_VAL:
-            var_dict['value'] = meta['value']
+            if MPI:
+                var_dict['value'] = meta['value']
+            else:
+                var_dict['value'] = _convert_ndarray_to_support_nans_in_json(system.get_val(name))
         else:
             var_dict['value'] = None
 
     return var_dict
 
 
+def _serialize_single_option(option):
+    """
+    Return a json-safe equivalent of the option.
+
+    The default_noraise function performs the datatype serialization, while this function takes
+    care of attributes specific to options dicts.
+
+    Parameters
+    ----------
+    option : object
+        Option to be serialized.
+
+    Returns
+    -------
+    object
+       JSON-safe serialized object.
+    """
+    val = option['value']
+    if not option['recordable']:
+        serialized_option = 'Not Recordable'
+    elif val is _UNDEFINED:
+        serialized_option = str(val)
+    else:
+        serialized_option = default_noraise(val)
+
+    return serialized_option
+
+
 def _get_tree_dict(system, component_execution_orders, component_execution_index,
                    is_parallel=False):
     """Get a dictionary representation of the system hierarchy."""
@@ -115,7 +194,7 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
 
         children = []
         for typ in ['input', 'output']:
-            for abs_name in system._var_abs_names[typ]:
+            for abs_name in system._var_abs2meta[typ]:
                 children.append(_get_var_dict(system, typ, abs_name))
 
             for prom_name in system._var_discrete[typ]:
@@ -130,9 +209,8 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
 
         children = []
         for s in system._subsystems_myproc:
-            if (s.name != '_auto_ivc'):
-                children.append(_get_tree_dict(s, component_execution_orders,
-                                component_execution_index, is_parallel))
+            children.append(_get_tree_dict(s, component_execution_orders,
+                            component_execution_index, is_parallel))
 
         if system.comm.size > 1:
             if system._subsystems_myproc:
@@ -151,7 +229,8 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
             tree_dict['linear_solver_options'] = None
         elif system.linear_solver:
             tree_dict['linear_solver'] = system.linear_solver.SOLVER
-            options = {k: system.linear_solver.options[k] for k in system.linear_solver.options}
+            options = {k: _serialize_single_option(system.linear_solver.options._dict[k])
+                       for k in system.linear_solver.options}
             tree_dict['linear_solver_options'] = options
         else:
             tree_dict['linear_solver'] = ""
@@ -162,7 +241,7 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
             tree_dict['nonlinear_solver_options'] = None
         elif system.nonlinear_solver:
             tree_dict['nonlinear_solver'] = system.nonlinear_solver.SOLVER
-            options = {k: system.nonlinear_solver.options[k]
+            options = {k: _serialize_single_option(system.nonlinear_solver.options._dict[k])
                        for k in system.nonlinear_solver.options}
             tree_dict['nonlinear_solver_options'] = options
         else:
@@ -171,7 +250,8 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
     else:
         if system.linear_solver:
             tree_dict['linear_solver'] = system.linear_solver.SOLVER
-            options = {k: system.linear_solver.options[k] for k in system.linear_solver.options}
+            options = {k: _serialize_single_option(system.linear_solver.options._dict[k])
+                       for k in system.linear_solver.options}
             tree_dict['linear_solver_options'] = options
         else:
             tree_dict['linear_solver'] = ""
@@ -179,7 +259,7 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
 
         if system.nonlinear_solver:
             tree_dict['nonlinear_solver'] = system.nonlinear_solver.SOLVER
-            options = {k: system.nonlinear_solver.options[k]
+            options = {k: _serialize_single_option(system.nonlinear_solver.options._dict[k])
                        for k in system.nonlinear_solver.options}
             tree_dict['nonlinear_solver_options'] = options
 
@@ -197,10 +277,8 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
         if k in ['linear_solver', 'nonlinear_solver']:
             options[k] = system.options[k].SOLVER
         else:
-            if system.options._dict[k]['value'] is _UNDEFINED:
-                options[k] = str(system.options._dict[k]['value'])
-            else:
-                options[k] = system.options._dict[k]['value']
+            options[k] = _serialize_single_option(system.options._dict[k])
+
     tree_dict['options'] = options
 
     if not tree_dict['name']:
@@ -267,7 +345,8 @@ def _get_viewer_data(data_source):
         driver_name = driver.__class__.__name__
         driver_type = 'doe' if isinstance(driver, DOEDriver) else 'optimization'
 
-        driver_options = {key: val for key, val in driver.options.items()}
+        driver_options = {key: _serialize_single_option(driver.options._dict[key])
+                          for key in driver.options}
 
         if driver_type == 'optimization' and 'opt_settings' in dir(driver):
             driver_opt_settings = driver.opt_settings
@@ -437,7 +516,6 @@ def n2(data_source, outfile='n2.html', show_browser=True, embeddable=False,
     }
     libs = read_files(lib_dct.values(), libs_dir, 'js')
     src_names = \
-        'modal', \
         'utils', \
         'SymbolType', \
         'N2TreeNode', \
@@ -451,6 +529,7 @@ def n2(data_source, outfile='n2.html', show_browser=True, embeddable=False,
         'N2Search', \
         'N2Toolbar', \
         'N2Diagram', \
+        'NodeInfo', \
         'N2UserInterface', \
         'defaults', \
         'ptN2'
